@@ -1,6 +1,14 @@
+# Taking cue from Roger Bivand's maptools:
+.PBSddeEnv <- new.env(FALSE, parent=globalenv())  # be sure to exportPattern("^\\.PBS") in NAMESPACE
+
 .onLoad <- function(lib,pkg)
 {
-	library.dynam("PBSddesolve", pkg, lib);
+	library.dynam("PBSddesolve", pkg, lib)
+}
+
+.onAttach <- function(lib, pkg)
+{
+        # obtain values necessary for the welcome message
 	pkg_info <- utils::sessionInfo( package="PBSddesolve" )$otherPkgs$PBSddesolve
 	if( is.character( pkg_info$Packaged ) )
 		pkg_date <- strsplit( pkg_info$Packaged, " " )[[1]][1]
@@ -11,7 +19,7 @@
 	
 	packageStartupMessage("
 -----------------------------------------------------------
-PBSddesolve ", pkg_info$Version, " -- Copyright (C) 2007-2012 Fisheries and Oceans Canada
+PBSddesolve ", pkg_info$Version, " -- Copyright (C) 2007-2013 Fisheries and Oceans Canada
 (based  on solv95 by Simon Wood)
 
 A complete user guide 'PBSddesolve-UG.pdf' is located at 
@@ -26,4 +34,7 @@ http://code.google.com/p/pbs-software/
 
 ")
 }
+.onUnload <- function(libpath) {
+	rm(.PBSddeEnv)
+}
 
